@@ -8,4 +8,6 @@
  */
 mod search;
 
-pub use search::{score};
+pub use search::{
+    get_heatmap_str, find_best_match, score, Score
+};
